Startup views — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Web side development »
- The View system »

# Startup views

(`cubicweb.web.views.startup`)

The usual selectors are no_rset or yes. These views don’t apply to a result set.

index
  This view defines the home page of your application. It does not require a result set to apply to.
schema
  A view dedicated to the display of the schema of the instance

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Web side development »
- The View system »